@@ -19,10 +19,10 @@ GNU Affero General Public License for more details.
 You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
-__version__ = "0.2.0"
+__version__ = "0.3.4"
 
 from kxy.api import *
 from kxy.regression import *
 from kxy.classification import *
 from kxy.asset_management import *
-from kxy.data import *
\ No newline at end of file
+from kxy.pandas_extension import *
\ No newline at end of file
